package WordList::CryptoCurrency::Catalog::NameSymbol;

our $DATE = '2018-01-07'; # DATE
our $VERSION = '20180106'; # VERSION

use WordList;
our @ISA = qw(WordList);

our %STATS = ("num_words",1384,"avg_word_len",15.264450867052,"shortest_word_len",7,"longest_word_len",35,"num_words_contains_whitespace",1384,"num_words_contains_unicode",0,"num_words_contains_nonword_chars",1384); # STATS

1;
# ABSTRACT: List of cryptocurrency names (and their symbols)

=pod

=encoding UTF-8

=head1 NAME

WordList::CryptoCurrency::Catalog::NameSymbol - List of cryptocurrency names (and their symbols)

=head1 VERSION

This document describes version 20180106 of WordList::CryptoCurrency::Catalog::NameSymbol (from Perl distribution WordLists-CryptoCurrency-Catalog), released on 2018-01-07.

=head1 SYNOPSIS

 use WordList::CryptoCurrency::Catalog::NameSymbol;

 my $wl = WordList::CryptoCurrency::Catalog::NameSymbol->new;

 # Pick a (or several) random word(s) from the list
 my $word = $wl->pick;
 my @words = $wl->pick(3);

 # Check if a word exists in the list
 if ($wl->word_exists('foo')) { ... }

 # Call a callback for each word
 $wl->each_word(sub { my $word = shift; ... });

 # Get all the words
 my @all_words = $wl->all_words;

=head1 STATISTICS

 +----------------------------------+-----------------+
 | key                              | value           |
 +----------------------------------+-----------------+
 | avg_word_len                     | 15.264450867052 |
 | longest_word_len                 | 35              |
 | num_words                        | 1384            |
 | num_words_contains_nonword_chars | 1384            |
 | num_words_contains_unicode       | 0               |
 | num_words_contains_whitespace    | 1384            |
 | shortest_word_len                | 7               |
 +----------------------------------+-----------------+

The statistics is available in the C<%STATS> package variable.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/WordLists-CryptoCurrency-Catalog>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-WordLists-CryptoCurrency-Catalog>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordLists-CryptoCurrency-Catalog>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__DATA__
0x (ZRX)
10M Token (10MT)
1337 (1337)
2GIVE (2GIVE)
300 Token (300)
42-coin (42)
808Coin (808)
8Bit (8BIT)
9COIN (9COIN)
ALIS (ALIS)
ALQO (ALQO)
ANRYZE (RYZ)
APX (APX)
ARbit (ARB)
ATBCoin (ATB)
ATLANT (ATL)
ATMChain (ATM)
ATMCoin (ATMC)
Abjcoin (ABJ)
Abncoin (ABN)
Accelerator Network (ACC)
Ace (ACE)
Aces (ACES)
Achain (ACT)
Acoin (ACOIN)
AdCoin (ADCOIN)
AdEx (ADX)
AdShares (ADST)
Adelphoi (ADL)
Advanced Internet Blocks (AIB)
Adzcoin (ADZ)
Aeon (AEON)
Aerium (AERM)
Aeron (ARN)
Aeternity (AE)
Agoras Tokens (AGRS)
Agrello (DLT)
AgrolifeCoin (AGLC)
Aidos Kuneen (ADK)
Aion (AION)
AirSwap (AST)
AirToken (AIR)
Akuya Coin (AKY)
AllSafe (ASAFE2)
Allion (ALL)
AlpaCoin (APC)
Alphabit (ABC)
AltCommunity Coin (ALTCOM)
Altcoin (ALT)
AmberCoin (AMBER)
Ambrosus (AMB)
Ammo Reloaded (AMMO)
AmsterdamCoin (AMS)
AnarchistsPrime (ACP)
Animecoin (ANI)
Anoncoin (ANC)
AntiBitcoin (ANTI)
Antilitecoin (ALTC)
Antimatter (ANTX)
AppleCoin (APW)
AquariusCoin (ARCO)
Aragon (ANT)
Arcade Token (ARCADE)
ArcticCoin (ARC)
Ardor (ARDR)
Argentum (ARG)
Argus (ARGUS)
Aricoin (ARI)
Ark (ARK)
ArtByte (ABY)
Artex Coin (ATX)
Asch (XAS)
Aseancoin (ASN)
AsiaCoin (AC)
Asiadigicoin (ADCN)
Astro (ASTRO)
Atmos (ATMS)
Atomic Coin (ATOM)
AudioCoin (ADC)
Augur (REP)
Auroracoin (AUR)
AurumCoin (AU)
Authorship (ATS)
Autonio (NIO)
AvatarCoin (AV)
Aventus (AVT)
Avoncoin (ACN)
Axiom (AXIOM)
B2B (B2B)
B3Coin (B3)
BCAP (BCAP)
BERNcash (BERN)
BITFID (FID)
BLOCKv (VEE)
BLUE (BLUE)
BOAT (BOAT)
BOScoin (BOS)
BROTHER (BRAT)
BT1 [CST] (BT1)
BT2 [CST] (BT2)
BTCMoon (BTCM)
BTCtalkcoin (TALK)
BTSR (BTSR)
Bancor (BNT)
Bankcoin (B@)
Basic Attention Token (BAT)
Bastonet (BSN)
BatCoin (BATCOIN)
Bata (BTA)
Beatcoin (XBTS)
BeaverCoin (BVC)
Bela (BELA)
BenjiRolls (BENJI)
BestChain (BEST)
BetaCoin (BETACOIN)
BiblePay (BBP)
Bibox Token (BIX)
BigONE Token (BIG)
BigUp (BIGUP)
BillaryCoin (BLRY)
Billionaire Token (XBL)
Binance Coin (BNB)
BioBar (BIOB)
BiosCrypto (BIOS)
BipCoin (BIP)
Birds (BIRDS)
Bismuth (BIS)
Bit20 (BTWTY)
BitAlphaCoin (BAC)
BitAsean (BAS)
BitBar (BTB)
BitBay (BAY)
BitBean (BITB)
BitBoost (BBT)
BitClave (BITCLAVE)
BitCoal (COAL)
BitConnect (BCC)
BitDice (CSNO)
BitQuark (BTQ)
BitSend (BSD)
BitSerial (BTE)
BitShares (BTS)
BitSoar (BSR)
BitTokens (BXT)
Bitair (BTCA)
Bitbase (BTBc)
Bitcedi (BXC)
Bitcloud (BTDX)
Bitcoin (BTC)
Bitcoin 21 (XBTC21)
Bitcoin Cash (BCH)
Bitcoin Diamond (BCD)
Bitcoin Fast (BCF)
Bitcoin Gold (BTG)
Bitcoin Planet (BTPL)
Bitcoin Plus (XBC)
Bitcoin Red (BTCRED)
Bitcoin Scrypt (BTCS)
Bitcoin Silver (BTCSILVER)
Bitcoin Unlimited (BTU)
Bitcoin2x (BTC2X)
BitcoinDark (BTCD)
BitcoinX [Futures] (BCX)
BitcoinZ (BTCZ)
Bitcore (BTX)
Bitcrystals (BCY)
Bitcurrency (BTCR)
Bitdeal (BDL)
Bitgem (BITGEM)
Bitmark (BITMARK)
Bitok (BITOK)
Bitpark Coin (BPC)
Bitradio (BRO)
Bitstar (BITS)
Bitswift (SWIFT)
Bitvolt (VOLT)
Bitz (BITZ)
Bitzeny (ZNY)
BlackCoin (BLK)
Blackmoon Crypto (BMC)
Blackstar (BSTAR)
BlakeStar (BLAS)
Blakecoin (BLC)
BlazeCoin (BLZ)
BlazerCoin (BLAZR)
Blitzcash (BLITZ)
BlockCAT (CAT)
BlockCDN (BCDN)
BlockMason Credit Protocol (BCPT)
BlockPay (BLOCKPAY)
Blockchain Index (BLX)
Blocknet (BLOCK)
Blockpool (BPL)
Blocktix (TIX)
BlueCoin (BLU)
BnrtxCoin (BNX)
Bodhi (BOT)
Bolenum (BLN)
Bolivarcoin (BOLI)
Bongger (BGR)
Bonpay (BON)
Boolberry (BBR)
BoostCoin (BOST)
Bounty0x (BNTY)
Bowhead (AHT)
BowsCoin (BSC)
Braincoin (BRAIN)
Bread (BRD)
Breakout (BRK)
Breakout Stake (BRX)
BriaCoin (BRIA)
BridgeCoin (BCO)
BritCoin (BRIT)
Bubble (BUB)
Bulwark (BWK)
BumbaCoin (BUMBA)
BunnyCoin (BUN)
Burst (BURST)
BurstOcean (OCEAN)
BuzzCoin (BUZZ)
Byteball Bytes (GBYTE)
Bytecent (BYC)
Bytecoin (BCN)
Bytom (BTM)
C-Bit (XCT)
CBD Crystals (CBD)
CCMiner (CCM100)
CHIPS (CHIPS)
COMSA [ETH] (CMSETH)
COMSA [XEM] (CMSXEM)
CORION (COR)
COSS (COSS)
CRTCoin (CRT)
CVCoin (CVCOIN)
Cabbage (CAB)
CacheCoin (CACH)
Californium (CF)
CaliphCoin (CALC)
CampusCoin (CMPCO)
Canada eCoin (CDN)
CannaCoin (CCN)
CannabisCoin (CANN)
Cannation (CNNC)
Cappasity (CAPP)
Capricoin (CPC)
CarTaxi Token (CTX)
Carboncoin (CARBON)
Cardano (ADA)
Cash Poker Pro (CASHPOKERPRO)
Cashcoin (CASH)
Cashme (CME)
Casino (CASINO)
CasinoCoin (CSC)
Catcoin (CATCOIN)
Ccore (CCO)
Centra (CTR)
Centurion (CNT)
ChainCoin (CHC)
ChainLink (LINK)
ChanCoin (4CHN)
Change (CAG)
Cheapcoin (CHEAP)
ChessCoin (CHESS)
Chronobank (TIME)
Chronologic (DAY)
Chronos (CRX)
Cindicator (CND)
Circuits of Value (COVAL)
Civic (CVC)
Clams (CLAM)
ClearPoll (POLL)
CloakCoin (CLOAK)
ClubCoin (CLUB)
CoExistCoin (COXST)
Cobinhood (COB)
Cofound.it (CFI)
Coimatic 2.0 (CTIC2)
Coimatic 3.0 (CTIC3)
Coin(O) (CNO)
Coin2.1 (C2)
CoinDash (CDT)
Coinonat (CXT)
CoinonatX (XCXT)
ColossusCoinXT (COLX)
Colossuscoin V2 (CV2)
Comet (COMET)
Compcoin (CMP)
CompuCoin (CPN)
Concoin (CONX)
Condensate (RAIN)
Confido (CFD)
Copico (XCPO)
Corethum (CRTM)
CorgiCoin (CORG)
Counterparty (XCP)
Coupecoin (COUPE)
Crave (CRAVE)
Cream (CRM)
Creatio (XCRE)
Creativecoin (CREA)
Credence Coin (CRDNC)
Creditbit (CRB)
Credo (CREDO)
CrevaCoin (CREVA)
CrowdCoin (CRC)
Crown (CRW)
CryptCoin (CRYPT)
Crypto (CTO)
Crypto Bullion (CBX)
CryptoCarbon (CCRB)
CryptoEscudo (CESC)
CryptoForecast (CFT)
CryptoInsight (TKR)
CryptoPing (PING)
CryptoWorldX Token (CWXT)
Cryptojacks (CJ)
Cryptonex (CNX)
Cryptonite (XCN)
Cryptopay (CPAY)
Crystal Clear  (CCT)
Cthulhu Offerings (OFF)
Cubits (CUBIT)
Curecoin (CURE)
CybCSec (XCS)
CyberCoin (CC)
CyberMiles (CMT)
Cycling Coin (CYC)
Cyder (CYDER)
Cypher (CYP)
DAO.Casino (BET)
DAPPSTER (DLISK)
DCORP (DRP)
DECENT (DCT)
DEW (DEW)
DFSCoin (DFS)
DIBCOIN (DIBC)
DIMCOIN (DIM)
DNotes (NOTE)
DROXNE (DRXNE)
Dai (DAI)
Dalecoin (DALC)
Darcrus (DAR)
DarkLisk (DISK)
Darsek (KED)
Dash (DASH)
Dashcoin (DSH)
Dashs (DASHS)
Databits (DTB)
Datum (DAT)
DavorCoin (DAV)
DaxxCoin (DAXX)
Debitcoin (DBTC)
DecentBet (DBET)
Decentraland (MANA)
Decision Token (HST)
Decred (DCR)
DeepBrain Chain (DBC)
DeepOnion (ONION)
Delphy (DPY)
DeltaCredits (DCRE)
Denarius (DNR)
Dent (DENT)
Dentacoin (DCN)
Desire (DSR)
Destiny (DES)
DeusCoin (DEUS)
Deutsche eMark (DEM)
Diamond (DMD)
DigiByte (DGB)
DigiCube (CUBE)
DigiPulse (DGPT)
Digital Bullion Gold (DBG)
Digital Credits (DGCS)
Digital Money Bits (DMB)
Digital Rupees (DRS)
DigitalDevelopersFund (DDF)
DigitalNote (XDN)
DigitalPrice (DP)
Digitalcoin (DGC)
DigixDAO (DGD)
Dimecoin (DIME)
DimonCoin (FUDD)
Dinastycoin (DCY)
Divi (DIVX)
Dix Asset (DIX)
Dogecoin (DOGE)
Dollar Online (DOLLAR)
Dollarcoin (DLC)
DomRaider (DRT)
Donationcoin (DON)
DopeCoin (DOPE)
Dotcoin (DOT)
Dovu (DOVU)
DraftCoin (DFT)
Dragonchain (DRGN)
Dreamcoin (DRM)
DubaiCoin (DBIX)
Dubstep (DUB)
Dutch Coin (DUTCH)
Dynamic (DYN)
Dynamic Trading Rights (DTR)
DynamicCoin (DMC)
E-Dinar Coin (EDR)
E-coin (ECN)
E4ROW (E4ROW)
EA Coin (EAG)
ECC (ECC)
EDRCoin (EDRC)
EGO (EGO)
ELTCOIN (ELTCOIN)
ENTCash (ENTCASH)
EOS (EOS)
EOT Token (EOT)
ERC20 (ERC20)
ETHGAS (EGAS)
ETHLend (LEND)
EXRNchain (EXRN)
EagleCoin (EAGLE)
EarthCoin (EAC)
Ebittree Coin (EBT)
EcoCoin (ECO)
Ecobit (ECOB)
Edgeless (EDG)
EggCoin (EGG)
Eidoo (EDO)
Einsteinium (EMC2)
Elacoin (ELC)
Elastic (XEL)
Elcoin (EL)
Electra (ECA)
Electroneum (ETN)
Elementrem (ELE)
Elixir (ELIX)
Ellaism (ELLA)
Elysium (ELS)
EmberCoin (EMB)
Embers (MBRS)
Emerald Crypto (EMD)
Emercoin (EMC)
Emphy (EPY)
EncrypGen (DNA)
EncryptoTel [WAVES] (ETTWAVES)
Energo (TSL)
Energycoin (ENRG)
Enigma (XNG)
Enigma Project (ENG)
Enjin Coin (ENJ)
EquiTrader (EQT)
Ergo (EFYT)
Eroscoin (ERO)
Eryllium (ERY)
Escroco (ESC)
Espers (ESP)
Eternity (ENT)
EthBet (EBET)
Ethbits (ETBS)
Ethereum (ETH)
Ethereum Cash (ECASH)
Ethereum Classic (ETC)
Ethereum Dark (ETHD)
Ethereum Gold (ETG)
Ethereum Lite (ELITE)
Ethereum Movie Venture (EMV)
Etheriya (RIYA)
Etheroll (DICE)
Etherparty (FUEL)
Ethos (ETHOS)
Eurocoin (EUC)
EuropeCoin (ERC)
EventChain (EVC)
EverGreenCoin (EGC)
Everex (EVX)
Everus (EVR)
Evil Coin (EVIL)
Evotion (EVO)
Exchange Union (XUC)
ExchangeN (EXN)
ExclusiveCoin (EXCL)
Expanse (EXP)
Experience Points (XP)
FAPcoin (FAP)
FIMKrypto (FIMK)
FLiK (FLIK)
FORCE (FOR)
FUNCoin (FUNC)
Faceblock (FBL)
Facecoin (FC)
Factom (FCT)
FairCoin (FAIR)
Fantomcoin (FCN)
Farad (FRD)
Fargocoin (FRGC)
Farstcoin (FRCT)
Fastcoin (FST)
Fazzcoin (FAZZ)
Feathercoin (FTC)
FedoraCoin (TIPS)
FidentiaX (FDX)
Filecoin [Futures] (FIL)
FinCoin (FNC)
FireFlyCoin (FFC)
Firecoin (FIRE)
First Bitcoin (BIT)
First Bitcoin Capital (BITCF)
FirstBlood (1ST)
FirstCoin (FRST)
FlappyCoin (FLAP)
Flash (FLASH)
FlavorCoin (FLVR)
Flaxscript (FLAX)
Flixxo (FLIXX)
FlorinCoin (FLO)
FlutterCoin (FLT)
Flycoin (FLY)
FlypMe (FYP)
FoldingCoin (FLDC)
Fonziecoin (FONZ)
Footy Cash (XFT)
Francs (FRN)
Franko (FRK)
FrankyWillCoin (FRWC)
Frazcoin (FRAZ)
Freicoin (FRC)
FuckToken (FUCK)
FuelCoin (FC2)
FujiCoin (FJC)
Fujinto (NTO)
FunFair (FUN)
FundYourselfNow (FYN)
FutCoin (FUTC)
FuturXe (FXE)
FuzzBalls (FUZZ)
G3N (G3N)
GAIA (GAIA)
GAY Money (GAY)
GBCGoldCoin (GBC)
GCoin (GCN)
GOLD Reward Token (GRX)
GPU Coin (GPU)
GXShares (GXS)
Gambit (GAM)
Game (GAME2)
GameBet Coin (GBT)
GameCredits (GAME)
GameLeagueCoin (GML)
GameUnits (UNITS)
GanjaCoin (MRJA)
Gapcoin (GAP)
Gas (GAS)
GeertCoin (GEERT)
Genaro Network (GNX)
Genesis Vision (GVT)
GeoCoin (GEO)
GeyserCoin (GSR)
Gifto (GTO)
Giga Watt Token (WTT)
Gimli (GIM)
GlassCoin (GLS)
Global Business Revolution (GBRC)
Global Currency Reserve (GCR)
Global Tour Coin (GTC)
GlobalBoost-Y (BSTY)
GlobalCoin (GLC)
GlobalToken (GLT)
Gnosis (GNO)
GoByte (GBX)
Gold Pressed Latinum (GPL)
GoldBlocks (GB)
GoldCoin (GLD)
GoldMaxCoin (GMX)
GoldPieces (GP)
GoldReserve (XGR)
GoldUnionCoin (GUC)
Golem (GNT)
Golfcoin (GOLF)
Golos (GOLOS)
Golos Gold (GBG)
Goodomy (GOOD)
Granite (GRN)
Grantcoin (GRT)
Greencoin (GRE)
Grid+ (GRID)
GridCoin (GRC)
Grimcoin (GRIM)
Groestlcoin (GRS)
Growers International (GRWI)
GuccioneCoin (GUCCIONE)
Gulden (NLG)
Guncoin (GUN)
HEAT (HEAT)
HEROcoin (PLAY)
HODL Bucks (HDLB)
HOdlcoin (HODL)
HTML5COIN (HTML5)
HTMLCOIN (HTML)
Halcyon (HAL)
Halloween Coin (HALLO)
Happy Creator Coin (HCC)
Happycoin (HPC)
HarmonyCoin (HMC)
Hawala.Today (HAT)
HealthyWormCoin (WORM)
Hedge (HDG)
Helleniccoin (HNC)
HelloGold (HGT)
HempCoin (HMP) (HMP)
HempCoin (THC)
Hexx (HXX)
HiCoin (XHI)
High Gain (HIGH)
High Voltage (HVCO)
HitCoin (HTC)
Hive (HVN)
HoboNickels (HBN)
HollyWoodCoin (HWC)
HomeBlockCoin (HBC)
Honey (HONEY)
Hshare (HSR)
Hubii Network (HBT)
Humaniq (HMQ)
Huncoin (HUNCOIN)
HunterCoin (HUC)
Hush (HUSH)
Hyper (HYPER)
Hyper Pay (HPY)
Hyper TV (HYTV)
HyperStake (HYP)
I/O Coin (IOC)
I0Coin (I0C)
ICO OpenLedger (ICOO)
ICOBID (ICOB)
ICON (ICX)
ICOS (ICOS)
ION (ION)
IOTA (MIOTA)
Iconic (ICON)
Iconomi (ICN)
Ignis (IGNIS)
Impact (IMX)
ImpulseCoin (IMPS)
InPay (INPAY)
IncaKoin (NKA)
Incent (INCNT)
Independent Money System (IMS)
India Coin (INDIA)
Indorse Token (IND)
InfChain (INF)
Infinitecoin (IFC)
Infinity Economics (XIN)
Infinity Pay (IPY)
InflationCoin (IFLT)
Influxcoin (INFX)
Ink (INK)
Innova (INN)
InsaneCoin (INSN)
Intelligent Trading Tech (ITT)
IntenseCoin (ITNS)
International Diamond (INTLDIAMOND)
Internet of People (IOP)
Internet of Things (XOT)
Internxt (INXT)
Interstellar Holdings (HOLD)
Interzone (ITZ)
InvestFeed (IFT)
InvisibleCoin (IVZ)
IoT Chain (ITC)
IrishCoin (IRL)
IslaCoin (ISL)
Ixcoin (IXC)
Janus (JNS)
JavaScript Token (JS)
Jetcoin (JET)
Jewels (JWL)
Jin Coin (JIN)
Jinn (JINN)
JobsCoin (JOBS)
Joincoin (J)
Joulecoin (XJO)
Karbo (KRB)
Karmacoin (KARMA)
KashhCoin (KASHH)
Kayicoin (KAYI)
KekCoin (KEK)
KickCoin (KICK)
KiloCoin (KLC)
Kin (KIN)
KingN Coin (KINGN)
Kittehcoin (MEOW)
Kobocoin (KOBO)
Kolion (KLN)
Komodo (KMD)
Kore (KORE)
Kronecoin (KRONE)
KuCoin Shares (KCS)
Kubera Coin (KBR)
Kurrent (KURT)
KushCoin (KUSH)
Kyber Network (KNC)
LAToken (LA)
LAthaan (LTH)
LBRY Credits (LBC)
LEOcoin (LEO)
LIFE (LIFE)
LLToken (LLT)
LUXCoin (LUX)
Lampix (PIX)
LanaCoin (LANA)
LandCoin (LDCN)
Lazaruscoin (LAZ)
LePen (LEPEN)
LeaCoin (LEA)
Legends Room (LGD)
LetItRide (LIR)
LeviarCoin (XLC)
LevoPlus (LVPS)
Lex4All (LEX)
Lightning Bitcoin (LIGHTNINGBTC)
Linda (LINDA)
Link Platform (LNK)
LinkedCoin (LKC)
Linx (LINX)
Lisk (LSK)
LiteBar (LTB)
LiteBitcoin (LBTC)
LiteCoin Gold (LTG)
LiteCoin Ultra (LTCU)
LiteDoge (LDOGE)
Litecoin (LTC)
Litecoin Plus (LCP)
Litecred (LTCR)
LoMoCoin (LMC)
LockChain (LOC)
Loopring (LRC)
LottoCoin (LOT)
LuckChain (BASH)
Luna Coin (LUNA)
Lunyr (LUN)
Lykke (LKK)
MACRON (MCRN)
MCAP (MCAP)
MMXVI (MMXVI)
MSD (MSD)
MTMGaming (MTM)
Machinecoin (MAC)
Macro (MCR)
Madcoin (MDC)
Maecenas (ART)
Magi (XMG)
MagicCoin (MAGE)
Magnet (MAG)
Magnetcoin (MAGN)
Magnum (MGM)
MaidSafeCoin (MAID)
Maker (MKR)
Mao Zedong (MAO)
Marijuanacoin (MAR)
Marscoin (MARS)
MarteXcoin (MXT)
MarxCoin (MARX)
Master Swiscoin (MSCN)
Masternodecoin (MTNC)
Matchpool (GUP)
Matryx (MTX)
Mavro (MAVRO)
MaxCoin (MAX)
MazaCoin (MZC)
MediShares (MDS)
Medibloc (MED)
Megacoin (MEC)
Melon (MLN)
Memetic (PepeCoin) (MEME)
Mercury (MER)
Mercury Protocol (GMT)
MergeCoin (MGC)
Metal (MTL)
Metal Music Coin (MTLMC3)
MetalCoin (METAL)
Metaverse ETP (ETP)
MicroMoney (AMM)
MiloCoin (MILO)
Mincoin (MNC)
MindCoin (MND)
Minereum (MNE)
Miners' Reward Token (MRT)
Mineum (MNM)
Minex (MINEX)
MinexCoin (MNX)
Mintcoin (MINT)
MobileCash (MBL)
MobileGo (MGO)
Modum (MOD)
Moeda Loyalty Points (MDA)
Moin (MOIN)
MojoCoin (MOJO)
MonaCoin (MONA)
Monaco (MCO)
Monero (XMR)
Moneta (MONETA)
MonetaryUnit (MUE)
Monetha (MTH)
Money ($$$)
MoneyCoin (MONEY)
Monkey Project (MONK)
Monoeci (XMCC)
Monster Byte (MBI)
Mooncoin (MOON)
MorningStar (MRNG)
Mothership (MSP)
Motocoin (MOTO)
Musicoin (MUSIC)
Musiconomi (MCI)
MustangCoin (MST)
Mutual Coin (MUT)
MyBit Token (MYB)
MyWish (WISH)
Myriad (XMY)
Mysterium (MYST)
NAGA (NGC)
NAV Coin (NAV)
NEM (XEM)
NEO (NEO)
NEO GOLD (NEOG)
NEVERDIE (NDC)
NVO (NVST)
Namecoin (NMC)
NamoCoin (NAMO)
Natcoin (NTC)
Neblio (NEBL)
Nebulas (NAS)
Nekonium (NUKO)
NeosCoin (NEOS)
NetCoin (NETCOIN)
Netko (NETKO)
Network Token (NTWK)
Neumark (NEU)
Neuro (NRO)
Neutron (NTRN)
NevaCoin (NEVA)
NewYorkCoin (NYC)
Newbium (NEWB)
Nexium (NXC)
Nexus (NXS)
Nimiq (NET)
NoLimitCoin (NLC2)
NobleCoin (NOBL)
NodeCoin (NODC)
Novacoin (NVC)
NuBits (USNBT)
NuShares (NSR)
Nuls (NULS)
Numeraire (NMR)
Nxt (NXT)
Nyancoin (NYAN)
OAX (OAX)
OBITS (OBITS)
OCOW (OCOW)
OKCash (OK)
OX Fina (OX)
Obsidian (ODN)
Oceanlab (OCL)
Octanox (OTX)
OctoCoin (888)
Olympus Labs (MOT)
Omicron (OMC)
OmiseGO (OMG)
Omni (OMNI)
Onix (ONX)
Opal (OPAL)
Open Trading Network (OTN)
Operand (OP)
Opescoin (OPES)
Opus (OPT)
OracleChain (OCT)
Orbitcoin (ORB)
Orlycoin (ORLY)
Ormeus Coin (ORME)
OsmiumCoin (OS76)
Oxycoin (OXY)
Oyster Pearl (PRL)
P7Coin (P7C)
PACcoin (PAC)
PIECoin (PIE)
PIVX (PIVX)
PLNcoin (PLNC)
POLY AI (AI)
PRCoin (PRC)
PRIZM (PZM)
PX (PX)
Pabyosi Coin Special (PCS)
Pakcoin (PAK)
Pandacoin (PND)
Paragon (PRG)
ParallelCoin (DUO)
ParkByte (PKB)
Particl (PART)
Pascal Coin (PASC)
Pascal Lite (PASL)
Patientory (PTOY)
PayCoin (XPY)
PayCon (CON)
PayPeer (PAYP)
PayPie (PPP)
Payfair (PFR)
Paypex (PAYX)
Peacecoin (PEC)
PeepCoin (PCN)
Peercoin (PPC)
Peerplays (PPY)
PeopleCoin (MEN)
Pepe Cash (PEPECASH)
Pesetacoin (PTC)
PetroDollar (XPD)
Phantomx (PNX)
Philosopher Stones (PHS)
Phoenixcoin (PXC)
Phore (PHR)
Photon (PHO)
Piggycoin (PIGGY)
Pillar (PLR)
PinkCoin (PINK)
PinkDog (PDG)
Pioneer Coin (PCOIN)
PiplCoin (PIPL)
Pirate Blocks (SKULL)
Pirl (PIRL)
PizzaCoin (PIZZA)
PlatinumBAR (XPTX)
PlayerCoin (PLACO)
Playkey (PKT)
PlexCoin (PLX)
PlusCoin (PLC)
Pluton (PLU)
Po.et (POE)
PoSToken (POS)
PoSW Coin (POSW)
PokeCoin (POKE)
Polybius (PLBT)
PonziCoin (PONZI)
PopularCoin (POP)
Populous (PPT)
PosEx (PEX)
PostCoin (POST)
PotCoin (POT)
Power Ledger (POWR)
Presearch (PRE)
President Johnson (GARY)
President Trump (PRES)
Primalbase Token (PBT)
Primas (PST)
Prime-XI (PXI)
Primecoin (XPM)
Primulon (PRIMU)
Printerium (PRX)
PrismChain (PRM)
Privatix (PRIX)
ProChain (PROCHAIN)
ProCurrency (PROCURRENCY)
Project Decorum (PDC)
Project-X (NANOX)
Propy (PRO)
Prospectors Gold (PGL)
Protean (PRN)
Prototanium (PR)
Psilocybin (PSY)
Publica (PBL)
Pulse (PULSE)
Pura (PURA)
Pure (PURE)
PureVidz (VIDZ)
PutinCoin (PUT)
Pylon Network (PYLNT)
QASH (QASH)
QCash (QC)
QLINK (QLC)
Qbao (QBT)
Qibuck Asset (QBK)
Qora (QORA)
Qtum (QTUM)
Quantstamp (QSP)
Quantum (QAU)
Quantum Resistant Ledger (QRL)
Quark (QRK)
Quatloo (QTL)
QuazarCoin (QCN)
QubitCoin (Q2C)
Quebecoin (QBC)
Quotient (XQN)
Qvolta (QVT)
Qwark (QWARK)
RChain (RHOC)
REAL (REAL)
REX (REX)
RHFCoin (RHFC)
RSGPcoin (RSGP)
RabbitCoin (RBBT)
Radium (RADS)
RaiBlocks (XRB)
Raiden Network Token (RDN)
Rasputin Online Coin (ROC)
Ratecoin (XRA)
Rawcoin (XRC)
Rcoin (RCOIN)
Red Pulse (RPX)
RedCoin (RED)
ReddCoin (RDD)
ReeCoin (REE)
Regacoin (REGA)
Regalcoin (REC)
Remicoin (REMI)
Renos (RNS)
Request Network (REQ)
Revain (R)
RevolverCoin (XRE)
Rialto (XRL)
RichCoin (RICHX)
Ride My Car (RIDE)
Riecoin (RIC)
Rimbit (RBT)
Ripio Credit Network (RCN)
Ripple (XRP)
Ripto Bux (RBX)
Rise (RISE)
Rivetz (RVT)
RonPaulCoin (RPC)
Roofs (ROOFS)
RouletteToken (RLT)
Royal Kingdom Coin (RKC)
RoyalCoin (ROYAL)
Royalties (XRY)
Rubies (RBIES)
RubleBit (RUBIT)
Rubycoin (RBY)
Runners (RUNNERS)
Rupaya (RUPX)
Rupaya [OLD] (RUPXOLD)
Rupee (RUP)
RussiaCoin (RC)
Russian Mining Coin (RMC)
Rustbits (RUSTBITS)
SACoin (SAC)
SALT (SALT)
SHACoin (SHA)
SHIELD (XSH)
SIBCoin (SIB)
SIGMAcoin (SIGMA)
SIRIN LABS Token (SRN)
SISA (SISA)
SOILcoin (SOIL)
SONM (SNM)
STEX (STEX)
STRAKS (STAK)
Safe Exchange Coin (SAFEX)
Safe Trade Coin (XSTC)
SafeCoin (SFE)
SagaCoin (SAGA)
Sakuracoin (SKR)
SaluS (SLS)
Sand Coin (SND)
Santa Coin (STC)
Santiment Network Token (SAN)
Sativacoin (STV)
SatoshiMadness (MAD)
Save and Gain (SANDG)
Scorecoin (SCORE)
SecretCoin (SCRT)
SecureCoin (SRC)
Segwit2x [Futures] (B2X)
Selfiecoin (SLFI)
Senderon (SDRN)
Sequence (SEQ)
Sexcoin (SXC)
Shadow Token (SHDW)
ShadowCash (SDC)
Sharechain (SSS)
Sharkcoin (SAK)
ShellCoin (SHELL)
Shift (SHIFT)
Shilling (SH)
Shorty (SHORTY)
Siacoin (SC)
Signatum (SIGT)
Simple Token (ST)
SingularDTV (SNGLS)
SixEleven (611)
Skeincoin (SKC)
SkinCoin (SKIN)
Skycoin (SKY)
Slevin (SLEVIN)
Sling (SLING)
Smart Investment Fund Token (SIFT)
SmartBillions (SMARTBILLIONS)
SmartCash (SMART)
SmartCoin (SMC)
SmartMesh (SMT)
SmileyCoin (SMLY)
SnakeEyes (SNAKE)
Snovio (SNOV)
Soarcoin (SOAR)
Social (SCL)
Social Send (SEND)
SocialCoin (SOCC)
Sojourn (SOJ)
SolarCoin (SLR)
Solarflarecoin (SFC)
Solaris (XLR)
Soma (SCT)
SongCoin (SONG)
SoonCoin (SOON)
SophiaTX (SPHTX)
Sovereign Hero (HERO)
SpaceCoin (SPACE)
SpankChain (SPANK)
Spectrecoin (XSPEC)
Speedcash (SCS)
Sphere (SPHR)
Sphre AIR  (XID)
SportsCoin (SPORT)
SportyFi (SPF)
Spots (SPT)
SpreadCoin (SPR)
Sprouts (SPRTS)
SproutsExtreme (SPEX)
StarCash Network (STARS)
StarCredits (STRC)
Starbase (STAR)
Starta (STA)
Startcoin (START)
Status (SNT)
Stealthcoin (XST)
Steem (STEEM)
Steem Dollars (SBD)
Stellar (XLM)
Steps (STEPS)
Sterlingcoin (SLG)
Storj (STORJ)
Storjcoin X (SJCX)
Storm (STORM)
Stox (STX)
Stratis (STRAT)
Streamr DATAcoin (DATA)
Stress (STS)
StrikeBitClub (SBC)
StrongHands (SHND)
Substratum (SUB)
Sugar Exchange (SGR)
Sumokoin (SUMO)
SunContract (SNC)
Super Bitcoin (SBTC)
SuperCoin (SUPER)
SuperNET (UNITY)
Suretly (SUR)
SwagBucks (BUCKS)
SwapToken (TOKEN)
Swapcoin (SWP)
Swarm City (SWT)
Swing (SWING)
SydPak (SDP)
Syndicate (SYNX)
Synereo (AMP)
Synergy (SNRG)
Syscoin (SYS)
T-coin (TCOIN)
TAGRcoin (TAGR)
TEKcoin (TEK)
TIES Network (TIE)
TRON (TRX)
TaaS (TAAS)
TagCoin (TAG)
TajCoin (TAJ)
Tao (XTO)
Target Coin (TGT)
TattooCoin (Limited) (TLE)
TattooCoin (Standard Edition) (TSE)
TeamUp (TEAM)
TechShares (THS)
Tellurion (TELL)
TenX (PAY)
TeraCoin (TERA)
TerraNova (TER)
Terracoin (TRC)
TeslaCoilCoin (TESLA)
TeslaCoin (TES)
Tether (USDT)
Tezos (Pre-Launch) (XTZ)
The ChampCoin (TCC)
The Cypherfunks (FUNK)
The Vegan Initiative (XVE)
TheCreed (TCR)
TheGCCcoin (GCC)
Theresa May Coin (MAY)
Tierion (TNT)
Tigercoin (TGC)
Time New Bank (TNB)
Titcoin (TIT)
TittieCoin (TTC)
ToaCoin (TOA)
TodayCoin (TODAY)
TokenCard (TKN)
Tokes (TKS)
Tokugawa (TOK)
TopCoin (TOP)
Topaz Coin (TOPAZ)
Torcoin (TOR)
Tracto (TRCT)
TransferCoin (TX)
TrezarCoin (TZC)
Triaconta (TRIA)
Triangles (TRI)
TrickyCoin (TRICK)
Trident Group (TRDT)
Triggers (TRIG)
Tristar Coin (TSTR)
Trollcoin (TROLL)
Truckcoin (TRK)
TrueFlip (TFL)
TrumpCoin (TRUMP)
TrustPlus (TRUST)
TurboCoin (TURBO)
Tychocoin (TYCHO)
UAHPay (UAHPAY)
UFO Coin (UFO)
UG Token (UGT)
UGAIN (GAIN)
UNCoin (UNC)
UR (UR)
USDe (USDE)
UTRUST (UTK)
Ubiq (UBQ)
Ulatech (ULA)
Ultimate Secure Cash (USC)
UltraCoin (UTC)
UnbreakableCoin (UNB)
UniCoin (UNIC)
Unify (UNIFY)
Unikoin Gold (UKG)
United Bitcoin (UBTC)
Unitus (UIS)
Unity Ingot (UNY)
Universal Currency (UNIT)
UniversalRoyalCoin (UNRC)
Universe (UNI)
Unobtanium (UNO)
Unrealcoin (URC)
Upfiring (UFR)
Uquid Coin (UQC)
Uro (URO)
Useless Ethereum Token (UET)
UtaCoin (UTA)
VIBE (VIBE)
VIP Tokens (VIP)
VIVO (VIVO)
VPNCoin (VASH)
Valorbit (VAL)
VapersCoin (VPRC)
Vault Coin (VLTC)
Vcash (XVC)
VeChain (VEN)
VectorAI (VEC2)
Veltor (VLT)
Verge (XVG)
VeriCoin (VRC)
Verify (CRED)
Veritaseum (VERI)
VeriumReserve (VRM)
Veros (VRS)
Version (V)
Vertcoin (VTC)
Viacoin (VIA)
Viberate (VIB)
Virta Unique Coin (VUC)
Virtacoin (VTA)
Virtacoinplus (XVP)
VirtualCoin (VC)
Visio (VISIO)
Viuly (VIU)
Voise (VOISE)
VoteCoin (VOT)
Voxels (VOX)
Voyacoin (VOYA)
Vsync (VSX)
Vulcano (VULC)
WA Space (WA)
WARP (WARP)
WAX (WAX)
WINCOIN (WC)
WMCoin (WMC)
WaBi (WABI)
Wagerr (WGR)
Walton (WTC)
WandX (WAND)
Waves (WAVES)
Waves Community Token (WCT)
WavesGo (WGO)
WayGuide (WAY)
WeAreSatoshi (WSX)
WeTrust (TRST)
WhaleCoin (WHL)
WhiteCoin (XWC)
Wi Coin (WIC)
Wild Beast Block (WBB)
Wild Crypto (WILD)
Wings (WINGS)
Wink (WINK)
WomenCoin (WOMEN)
Woodcoin (LOG)
WorldCoin (WDC)
Worldcore (WRC)
Wowcoin (WOW)
Wyvern (WYV)
X-Coin (XCO)
X2 (X2)
XDE II (XDE2)
XGOX (XGOX)
XPlay (XPA)
XTD Coin (XTD)
XTRABYTES (XBY)
XYLO (XYLO)
Xaucoin (XAU)
Xaurum (XAUR)
Xenon (XNN)
Xios (XIOS)
Xonecoin (XOC)
YENTEN (YTN)
YOYOW (YOYOW)
Yacoin (YAC)
YashCoin (YASH)
Yellow Token (YEL)
Yescoin (YES)
Yocoin (YOC)
ZClassic (ZCL)
ZCoin (XZC)
ZSEcoin (ZSE)
Zayedcoin (ZYD)
Zcash (ZEC)
Zeitcoin (ZEIT)
ZenCash (ZEN)
ZenGold (ZENGOLD)
Zennies (ZENI)
Zephyr (ZEPH)
Zero (ZER)
ZetaMicron (ZMC)
Zetacoin (ZET)
Zeusshield (ZSC)
Zilbercoin (ZBC)
Zlancer (ZCG)
ZoZoCoin (ZZC)
Zoin (ZOI)
Zonecoin (ZNE)
ZrCoin (ZRC)
Zurcoin (ZUR)
adToken (ADT)
aelf (ELF)
bitBTC (BITBTC)
bitCNY (BITCNY)
bitEUR (BITEUR)
bitGold (BITGOLD)
bitJob (STU)
bitSilver (BITSILVER)
bitUSD (BITUSD)
bitqy (BQ)
district0x (DNT)
e-Gulden (EFL)
eBIT (EBIT)
eBitcoin (EBTC)
eBitcoinCash (EBCH)
eBoost (EBST)
eGold (EGOLD)
eLTC (ELTC2)
eREAL (EREAL)
eUSD (EUSD)
encryptotel-eth (ETTETH)
iBTC (IBTC)
iBank (IBANK)
iCoin (ICOIN)
iDice (ICE)
iEthereum (IETH)
iExec RLC (RLC)
iQuant (IQT)
iTicoin (ITI)
iXledger (IXT)
netBit (NBIT)
onG.social (ONG)
vSlice (VSL)
vTorrent (VTR)
